.. FreeGS documentation master file, created by
   sphinx-quickstart on Thu May 18 23:46:05 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to FreeGS's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   creating_equilibria
   input_and_output
   diagnostics
   tests
   optimisation

.. toctree::
   :maxdepth: 2
   :caption: API reference:

   API Reference <api>
             
Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
